"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultRateLimit = defaultRateLimit;
const utils_1 = require("@medusajs/framework/utils");
const get_default_options_1 = require("../../utils/get-default-options");
const get_ip_1 = require("../../utils/get-ip");
const set_rate_limit_headers_1 = require("../../utils/set-rate-limit-headers");
function defaultRateLimit(options = {}) {
    return async function (req, res, next) {
        const { limit, window, includeHeaders } = {
            ...(0, get_default_options_1.getDefaultOptions)(),
            ...options,
        };
        const cacheModule = req.scope.resolve(utils_1.Modules.CACHE);
        const ip = (0, get_ip_1.getIp)(req);
        const key = `rate-limit:${ip}`;
        const currentCount = (await cacheModule.get(key)) || 0;
        if (currentCount >= limit) {
            if (includeHeaders) {
                (0, set_rate_limit_headers_1.setRateLimitHeaders)(res, limit, 0);
            }
            res.status(429).send('Too many requests, please try again later.');
            return;
        }
        await cacheModule.set(key, currentCount + 1, window);
        if (includeHeaders) {
            (0, set_rate_limit_headers_1.setRateLimitHeaders)(res, limit, limit - (currentCount + 1));
        }
        next();
    };
}
//# sourceMappingURL=default-rate-limit.js.map